@@ -11,9 +11,10 @@ import org.gcube.portlets.user.td.wizardwidget.client.util.UtilsGXT3;
 
 import com.allen_sauer.gwt.log.client.Log;
 import com.google.gwt.core.client.Callback;
+import com.google.gwt.core.client.GWT;
+import com.google.gwt.dom.client.Element;
 import com.google.gwt.event.dom.client.KeyCodes;
 import com.google.gwt.user.client.Command;
-import com.google.gwt.dom.client.Element;
 import com.google.gwt.user.client.Event;
 import com.google.gwt.user.client.ui.Widget;
 import com.google.web.bindery.event.shared.EventBus;
@@ -45,9 +46,6 @@ public class WizardWindow extends Window {
 	protected String WIZARDHEIGHT = "520px";
 	protected boolean WIZARRESIZABLE = false;
 	protected boolean WIZARDCOLLAPSIBLE = true;
-	protected String BUTTONBACKLABEL = "Back";
-	protected String BUTTONNEXTLABEL = "Next";
-	protected String BUTTONFINISHLABEL = "Finish";
 	protected String title;
 
 	protected ArrayList<WizardCard> cardStack = new ArrayList<WizardCard>();
@@ -75,6 +73,7 @@ public class WizardWindow extends Window {
 	protected ToolBar cardMoveToolBar;
 
 	protected FillToolItem fillSpacingCardMoveToolBar;
+	protected WizardMessages msgs;
 
 	/**
 	 * Create a new Wizard Window with the specified title.
@@ -91,6 +90,8 @@ public class WizardWindow extends Window {
 		super();
 		this.title = title;
 		this.eventBus = eventBus;
+		this.msgs = GWT.create(WizardMessages.class);
+		
 		initWindow();
 
 		listeners = new ArrayList<WizardListener>();
@@ -103,7 +104,7 @@ public class WizardWindow extends Window {
 		cardMoveToolBar.setSpacing(2);
 		cardMoveToolBar.addStyleName(ThemeStyles.get().style().borderTop());
 
-		backButton = new TextButton(BUTTONBACKLABEL);
+		backButton = new TextButton(msgs.buttonBackLabel());
 		backButton.setIcon(ResourceBundle.INSTANCE.wizardPrevious());
 		backButton.setIconAlign(IconAlign.LEFT);
 
@@ -115,7 +116,7 @@ public class WizardWindow extends Window {
 
 		cardMoveToolBar.add(fillSpacingCardMoveToolBar);
 
-		nextButton = new TextButton(BUTTONNEXTLABEL);
+		nextButton = new TextButton(msgs.buttonNextLabel());
 		nextButton.setIcon(ResourceBundle.INSTANCE.wizardNext());
 		nextButton.setIconAlign(IconAlign.RIGHT);
 		nextButton.setTabIndex(1000);
@@ -303,7 +304,7 @@ public class WizardWindow extends Window {
 	 * to it.
 	 */
 	public void setNextButtonToFinish() {
-		nextButton.setText(BUTTONFINISHLABEL);
+		nextButton.setText(msgs.buttonNextLabel());
 		nextButton.setIcon(ResourceBundle.INSTANCE.wizardGo());
 		nextButton.setIconAlign(IconAlign.RIGHT);
 		nextButtonAction = new Command() {
